@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,9 +11,7 @@ LogInfo::LogInfo(QObject *parent)
 {
 }
 
-LogInfo::~LogInfo()
-{
-}
+LogInfo::~LogInfo() = default;
 
 void LogInfo::addInfoLogEntry(const QString &log)
 {
